<?php
if ( ! function_exists( 'pia_setup' ) ) {
	function pia_setup() {
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 600;
		}

		load_theme_textdomain( 'pia' );

		add_theme_support( 'custom-background' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );

		register_nav_menus( array(
			'primary' => __( 'Primary Navigation', 'pia' ),
		) );
	}
}
add_action( 'after_setup_theme', 'pia_setup' );

function pia_scripts() {
	wp_enqueue_style( 'open-sans' );
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'pia_custom_script', get_template_directory_uri() . '/inc/pia.js' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style( 'pia_style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'pia_scripts' );

require get_template_directory() . '/inc/customizer.php';


function pia_customize_css() {
	echo '<style type="text/css">';
		echo 'pre {
			border:4px solid ' . esc_attr( get_theme_mod( 'pia_accent_color','#990033' ) ) . '; }
			.widget-area,
			.reply,
			#entry-author-info,
			.pia-date{
				background:' . esc_attr( get_theme_mod( 'pia_accent_color','#990033' ) ) . '; }

			.entry-content a:hover,
			.entry-content a:focus,
			.entry-meta a:hover,
			.entry-meta a:focus,
			.menu a:hover,
			.menu a:focus,
			.nav-next a:hover,
			.nav-next a:focus,
			.nav-previous a:hover,
			.nav-previous a:focus,
			.front-title a:hover,
			.front-title a:focus,
			#site-description,
			#site-title a {
				color:' . esc_attr( get_theme_mod( 'pia_accent_color','#990033' ) ) . ';  }';

		echo '#today,
			.comment-body,
			.type-page, 
			.feat_next,
			.feat_prev,
			.type-attachment,
			.post,
			#menu ul ul a,
			#menu {
				background:' . esc_attr( get_theme_mod( 'pia_accent_color_black', '#000000' ) ) . '; }';

	echo '</style>';
}
add_action( 'wp_head', 'pia_customize_css' );


/* Post excerpt        utdrag*/
add_filter( 'get_the_excerpt', 'pia_custom_excerpt_more',100 );
add_filter( 'excerpt_more', 'pia_auto_excerpt_more',100 );
add_filter( 'the_content_more_link', 'pia_continue_reading_link', 100 );

function pia_continue_reading_link() {
	return ' <a href="' . get_permalink() . '">' . __( 'Continue reading ', 'pia' ) . get_the_title() . ' &rarr;</a>';
}

function pia_auto_excerpt_more( $more ) {
	return ' &hellip;' . pia_continue_reading_link();
}
add_filter( 'excerpt_more', 'pia_auto_excerpt_more' );

function pia_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= pia_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'pia_custom_excerpt_more' );



function pia_widgets() {

	/**
	 * Register widget areas (Sidebars).
	 */
	register_sidebar( array( 'name' => __( 'Top Widgetarea Left', 'pia' ), 'id' => 'sidebar-1' ) );
	register_sidebar( array( 'name' => __( 'Top Widgetarea Center', 'pia' ), 'id' => 'sidebar-2' ) );
	register_sidebar( array( 'name' => __( 'Top_Widgetarea Right', 'pia' ), 'id' => 'sidebar-3' ) );

	register_sidebar( array( 'name' => __( 'Footer Widgetarea Left', 'pia' ), 'id' => 'sidebar-4' ) );
	register_sidebar( array( 'name' => __( 'Footer Widgetarea Center', 'pia' ), 'id' => 'sidebar-5' ) );
	register_sidebar( array( 'name' => __( 'Footer Widgetarea Right', 'pia' ), 'id' => 'sidebar-6' ) );

	register_sidebar( array( 'name' => __( 'Footer Copyright', 'pia' ), 'id' => 'sidebar-7' ) );
}
add_action( 'widgets_init', 'pia_widgets' );


if ( ! function_exists( 'pia_meta' ) ) {

	/**
	 * Prints meta information for the current post.
	 */
	function pia_meta() {
		echo '<div class="entry-meta">';
		esc_html_e( 'Posted by ', 'pia' );
		the_author_posts_link();

		if ( is_single() ) {
			esc_html_e( ' on ','pia' );
			the_time( get_option( 'date_format' ) );
		}

		echo ' | ';

		if ( count( get_the_category() ) ) {
			esc_html_e( 'Categories: ', 'pia' );
			echo ' ' . get_the_category_list( ', ' ) . ' | ' ;
		}

		if ( get_the_tag_list() ) {
			esc_html_e( 'Tags: ', 'pia' );
			echo get_the_tag_list( '', ', ' );
			echo ' | ';
		}

		comments_popup_link();
		echo ' | ';
		edit_post_link( esc_html__( 'Edit', 'pia' ) . '<span class="screen-reader-text">' . get_the_title() . '</span>' );
		echo '</div>';
	}
}
